RecordSegment class

录制段数据模型

Constructors

RecordSegment({required int startTimeMs, required int endTimeMs, SegmentType type = SegmentType.normal, Map<String, dynamic>? extraData})
RecordSegment.fromJson(Map<String, dynamic> json)
JSON 反序列化支持
factory

Properties

durationMs int
获取段时长(毫秒)
no setter
endTimeMs int
结束时间(毫秒时间戳)
final
extraData Map<String, dynamic>?
额外数据
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimeMs int
开始时间(毫秒时间戳)
final
type SegmentType
录制段类型
final

Methods

contains(int timeMs) bool
检查是否包含指定时间点
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
JSON 序列化支持
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited