TimeScaleOption class

时间刻度配置选项

Constructors

TimeScaleOption({double scaleLineWidth = 1.0, double scaleLineHeight = 6.0, Color scaleTextColor = const Color(0xFF999999), Color scaleLineColor = const Color(0xFFCCCCCC), ScaleAlignment scaleAlignment = ScaleAlignment.bottom, double scaleTextSize = 10.0, FontWeight scaleTextWeight = FontWeight.normal})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleAlignment ScaleAlignment
刻度对齐方式
final
scaleLineColor Color
刻度线颜色
final
scaleLineHeight double
刻度线高度
final
scaleLineWidth double
刻度线宽度
final
scaleTextColor Color
刻度文字颜色
final
scaleTextSize double
刻度文字大小
final
scaleTextWeight FontWeight
刻度文字粗细
final

Methods

copyWith({double? scaleLineWidth, double? scaleLineHeight, Color? scaleTextColor, Color? scaleLineColor, ScaleAlignment? scaleAlignment, double? scaleTextSize, FontWeight? scaleTextWeight}) TimeScaleOption
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited