MiddleIndicatorOption class

中间指示器配置选项

Constructors

MiddleIndicatorOption({double length = 60.0, Color fillColor = const Color(0xFF0A59F7), bool showTimeText = true, TextStyle timeTextStyle = const TextStyle(color: Color(0xFF0A59F7), fontSize: 12.0, fontWeight: FontWeight.bold)})
const

Properties

fillColor Color
指示器颜色
final
hashCode int
The hash code for this object.
no setterinherited
length double
指示器长度(线的高度)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTimeText bool
是否显示时间文本
final
timeTextStyle TextStyle
时间文本样式
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited