TimeBarPainter class

时间轴绘制器

Inheritance

Constructors

TimeBarPainter({required List<RecordSegment> segments, required int currentTimeMs, required int leftTimeMs, required double scale, required VideoAreaOption videoAreaOption, required TimeScaleOption timeScaleOption, required MiddleIndicatorOption middleIndicatorOption, Color backgroundColor = const Color(0xFFF5F5F4), int tickIntervalMs = 3600000})

Properties

backgroundColor Color
背景颜色
final
currentTimeMs int
当前时间(毫秒)
final
hashCode int
The hash code for this object.
no setterinherited
leftTimeMs int
左侧边界时间(毫秒)
final
middleIndicatorOption MiddleIndicatorOption
中间指示器配置
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
缩放比例(像素/毫秒)
final
segments List<RecordSegment>
录制段列表
final
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
tickIntervalMs int
刻度间隔(毫秒)
final
timeScaleOption TimeScaleOption
时间刻度配置
final
videoAreaOption VideoAreaOption
视频区域配置
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant TimeBarPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited