TimeBarWidget class

时间轴主组件

Inheritance

Constructors

TimeBarWidget({Key? key, required List<RecordSegment> segments, required int currentTimeMs, int totalDurationMs = 86400000, int? startTimeMs, VideoAreaOption videoAreaOption = const VideoAreaOption(), TimeScaleOption timeScaleOption = const TimeScaleOption(), MiddleIndicatorOption middleIndicatorOption = const MiddleIndicatorOption(), bool showMiddleIndicator = true, TimeBarOption timeBarOption = const TimeBarOption(), double tickInterval = 10.0, ValueChanged<int>? onTimeChanged, ValueChanged<int>? onTimeChangeEnd, double minScale = 0.0000001, double maxScale = 0.1})
const

Properties

currentTimeMs int
当前时间(毫秒)
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxScale double
最大缩放级别 (像素/毫秒)
final
middleIndicatorOption MiddleIndicatorOption
中间指示器配置
final
minScale double
最小缩放级别 (像素/毫秒)
final
onTimeChanged ValueChanged<int>?
时间变化回调(拖动过程中高频触发)
final
onTimeChangeEnd ValueChanged<int>?
动作结束回调(由点击跳转、或拖拽结束后触发,适合处理网络请求)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<RecordSegment>
录制段列表
final
showMiddleIndicator bool
是否显示中间指示器
final
startTimeMs int?
开始时间(毫秒),默认为当天 00:00:00
final
tickInterval double
初始刻度间隔(像素/分钟)
final
timeBarOption TimeBarOption
容器配置
final
timeScaleOption TimeScaleOption
时间刻度配置
final
totalDurationMs int
总时长(毫秒),默认为24小时
final
videoAreaOption VideoAreaOption
视频区域配置
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TimeBarWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited