VideoAreaOption class
视频区域配置选项
Constructors
- VideoAreaOption({Color backgroundColor = const Color(0xFFE5E5E5), double height = 14.0, double topOffset = 30.0, double bottomOffset = 5.0, BorderRadius segmentBorderRadius = const BorderRadius.all(Radius.circular(2.0)), double segmentGap = 0.0, Color colorMapper(SegmentType type)?})
-
const
Properties
- backgroundColor → Color
-
背景颜色
final
- bottomOffset → double
-
底部偏移量
final
- colorMapper → Color Function(SegmentType type)?
-
自定义颜色映射方法
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
视频段高度
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentBorderRadius → BorderRadius
-
段圆角半径
final
- segmentGap → double
-
段之间的间隔
final
- topOffset → double
-
顶部偏移量
final
Methods
-
copyWith(
{Color? backgroundColor, double? height, double? topOffset, double? bottomOffset, BorderRadius? segmentBorderRadius, double? segmentGap, Color colorMapper(SegmentType type)?}) → VideoAreaOption -
getSegmentColor(
SegmentType type) → Color - 获取段颜色
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited