TimeBarOption class
时间轴容器配置选项
Constructors
- TimeBarOption({double width = double.infinity, double height = 80.0, Color backgroundColor = const Color(0xFFF5F5F4)})
-
const
Properties
- backgroundColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited